/**
 * Gaming Tools
 * Copyright (C) 2003  Michael Birken
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * @author Michael Birken (o__1@hotmail.com)
 * @version 2.1
 */
package gamingtools;

import java.applet.AudioClip;

/**
 * The <CODE>Audio</CODE> interface is a simple abstraction for playing music or
 * a sound effect. When this object is no longer needed, the
 * <CODE>dispose()</CODE> method should be invoked.
 */
public interface Audio extends AudioClip {

  /**
   * Registers an <CODE>AudioListener</CODE> with this <CODE>Audio</CODE>
   * object to receive notification of when the audio stops.
   * @param audioListener Called back when the audio stops.
   */
  public void setAudioListener(AudioListener audioListener);

  /**
   * Unregisters the <CODE>AudioListener</CODE> if there is one. This method is
   * equivalent to passing <CODE>null</CODE> to <CODE>setAudioListener()</CODE>.
   */
  public void clearAudioListener();

  /**
   * <P>Releases any system resources used by this object. An <CODE>Audio</CODE>
   * object cannot be used after calling this method.</P>
   * <P>The finalization process of the garbage collector also disposes of
   * the same system resources; however, since the finalization process may
   * not run to completion for a long duration, it is preferable to manually
   * free the resources by invoking this method.</P>
   */
  public void dispose();
}