/**
 * Meat Fighter
 * Copyright (C) 2003  Michael Birken
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Meat Fighter and JaminWare are trademarks of Michael Birken.
 * All Rights Reserved.
 * http://www.meatfighter.com
 * o__1@hotmail.com
 */
package meatfighter;

public abstract class InputSource {

  protected boolean left;
  protected boolean right;
  protected boolean up;
  protected boolean down;
  protected boolean punch;
  protected boolean kick;
  protected boolean block;
  protected boolean start;
  protected boolean quit;
  protected InputListener inputListener;

  public void setInputListener(InputListener inputListener) {
    this.inputListener = inputListener;
  }

  public void clearInputListener() {
    setInputListener(null);
  }

  public boolean isLeft() {
    return left;
  }

  public boolean isRight() {
    return right;
  }

  public boolean isUp() {
    return up;
  }

  public boolean isDown() {
    return down;
  }

  public boolean isPunch() {
    return punch;
  }

  public boolean isKick() {
    return kick;
  }

  public boolean isBlock() {
    return block;
  }

  public boolean isStart() {
    return start;
  }

  public boolean isQuit() {
    return quit;
  }

  protected void setLeft(boolean asserted) {
    left = asserted;
    if (inputListener != null && asserted) {
      inputListener.inputLeft();
    }
  }

  protected void setRight(boolean asserted) {
    right = asserted;
    if (inputListener != null && asserted) {
      inputListener.inputRight();
    }
  }

  protected void setUp(boolean asserted) {
    up = asserted;
    if (inputListener != null && asserted) {
      inputListener.inputUp();
    }
  }

  protected void setDown(boolean asserted) {
    down = asserted;
    if (inputListener != null && asserted) {
      inputListener.inputDown();
    }
  }

  protected void setPunch(boolean asserted) {
    punch = asserted;
    if (inputListener != null && asserted) {
      inputListener.inputPunch();
    }
  }

  protected void setKick(boolean asserted) {
    kick = asserted;
    if (inputListener != null && asserted) {
      inputListener.inputKick();
    }
  }

  protected void setBlock(boolean asserted) {
    block = asserted;
    if (inputListener != null && asserted) {
      inputListener.inputBlock();
    }
  }

  protected void setStart(boolean asserted) {
    start = asserted;
    if (inputListener != null && asserted) {
      inputListener.inputStart();
    }
  }

  protected void setQuit(boolean asserted) {
    quit = asserted;
    if (inputListener != null && asserted) {
      inputListener.inputQuit();
    }

    MeatFighter.getInstance().endGame();
  }
}