/**
 * Meat Fighter
 * Copyright (C) 2003  Michael Birken
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Meat Fighter and JaminWare are trademarks of Michael Birken.
 * All Rights Reserved.
 * http://www.meatfighter.com
 * o__1@hotmail.com
 */
package meatfighter;

import java.awt.*;
import java.awt.event.*;
import gamingtools.*;

public class KeyboardInputSource extends InputSource implements KeyListener {

  public static final int KEY_LEFT  = KeyEvent.VK_LEFT;
  public static final int KEY_RIGHT = KeyEvent.VK_RIGHT;
  public static final int KEY_UP    = KeyEvent.VK_UP;
  public static final int KEY_DOWN  = KeyEvent.VK_DOWN;
  public static final int KEY_PUNCH = KeyEvent.VK_D;
  public static final int KEY_KICK  = KeyEvent.VK_F;
  public static final int KEY_BLOCK = KeyEvent.VK_A;
  public static final int KEY_START = KeyEvent.VK_ENTER;
  public static final int KEY_QUIT  = KeyEvent.VK_ESCAPE;

  private boolean releasedPunch = true;
  private boolean releasedKick = true;
  private boolean releasedUp = true;
  private Frame frame;

  public KeyboardInputSource() {
    frame = GraphicsSource.getFrame();
    frame.requestFocus();
    frame.addKeyListener(this);
  }

  public void dispose() {
    frame.removeKeyListener(this);
  }

  protected void finalize() throws Throwable {
    dispose();
  }

  public void keyTyped(KeyEvent e) {
  }

  public void keyPressed(KeyEvent e) {
    switch(e.getKeyCode()) {
      case KEY_LEFT:
        setLeft(true);
        break;
      case KEY_RIGHT:
        setRight(true);
        break;
      case KEY_UP:
        if (releasedUp) {
          setUp(true);
          releasedUp = false;
        }
        break;
      case KEY_DOWN:
        setDown(true);
        break;
      case KEY_PUNCH:
        if (releasedPunch) {
          setPunch(true);
          releasedPunch = false;
        }
        break;
      case KEY_KICK:
        if (releasedKick) {
          setKick(true);
          releasedKick = false;
        }
        break;
      case KEY_BLOCK:
        setBlock(true);
        break;
      case KEY_QUIT:
        setQuit(true);
        break;
      case KEY_START:
        setStart(true);
        break;
    }
  }

  public void keyReleased(KeyEvent e) {
    switch(e.getKeyCode()) {
      case KEY_LEFT:
        setLeft(false);
        break;
      case KEY_RIGHT:
        setRight(false);
        break;
      case KEY_UP:
        setUp(false);
        releasedUp = true;
        break;
      case KEY_DOWN:
        setDown(false);
        break;
      case KEY_PUNCH:
        setPunch(false);
        releasedPunch = true;
        break;
      case KEY_KICK:
        setKick(false);
        releasedKick = true;
        break;
      case KEY_BLOCK:
        setBlock(false);
        break;
      case KEY_QUIT:
        setQuit(false);
        break;
      case KEY_START:
        setStart(false);
        break;
    }
  }

  public boolean isPunch() {
    boolean asserted = punch;
    punch = false;
    return asserted;
  }

  public boolean isKick() {
    boolean asserted = kick;
    kick = false;
    return asserted;
  }

  public boolean isUp() {
    boolean asserted = up;
    up = false;
    return asserted;
  }
}