/**
 * Meat Fighter
 * Copyright (C) 2003  Michael Birken
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Meat Fighter and JaminWare are trademarks of Michael Birken.
 * All Rights Reserved.
 * http://www.meatfighter.com
 * o__1@hotmail.com
 */
package meatfighter;

import gamingtools.*;
import java.awt.*;
import javax.swing.*;
import java.awt.event.*;
import java.awt.image.*;
import java.util.logging.*;
import java.util.*;

public class MeatFighter extends InputAdapter {

  public static final int EXIT_NORMAL = 0;
  public static final int EXIT_UPDATE_JRE = 1;
  public static final int EXIT_VERSION = 2;
  public static final int EXIT_FATAL = 3;

  public static final String MEAT_FIGHTER_VERSION = "2.0";

  private static MeatFighter singleton;

  private int startStage;
  private boolean pressedStart;
  private boolean humanBeef;

  public static MeatFighter getInstance() {
    return singleton;
  }

  public static void main(String[] args) {
    new MeatFighter(args);
  }

  private MeatFighter(String[] args) {
    try {
      singleton = this;
      GraphicsSource.enterDisplayMode(640, 480);
      GraphicsSource.getFrame().setTitle("Meat Fighter: The Wiener Warrior");
      GraphicsSource.setRenderListener(new ProgressBar());
      GraphicsSource.startAnimation(24, 0);

      Class.forName("meatfighter.Jukebox");
      Class.forName("meatfighter.Gallery");

      GraphicsSource.setRenderListener(
          Introduction.getInstance(Introduction.STATE_JAMINWARE));

      InputFactory.getInputSource().setInputListener(this);

    } catch(Throwable t) {
      exitOnFatal(t);
    }
  }

  public void inputStart() {
    if (pressedStart)
      return;
    else
      pressedStart = true;
    Jukebox.GIBBER3.setAudioListener(new AudioListener() {
      public void audioStopped() {
        startTheGame();
      }
    });
    Jukebox.stopMusic();
    Jukebox.GIBBER3.play();
  }

  public void continueTheGame() {
    Jukebox.GIBBER3.setAudioListener(new AudioListener() {
      public void audioStopped() {
        if (humanBeef)
          characterSelected(7);
        else
          GraphicsSource.setRenderListener(new SelectCharacter());
      }
    });
    Jukebox.stopMusic();
    Jukebox.GIBBER3.play();
  }

  public void startTheGame() {
    stageNum = startStage;
    if (humanBeef)
      characterSelected(7);
    else
      GraphicsSource.setRenderListener(new SelectCharacter());
  }

  public void characterSelected(int fNum) {
    InputFactory.getInputSource().clearInputListener();
    fighterNum = fNum;
    startVS();
  }

  public void startStage() {
    GraphicsSource.setRenderListener(
        new GenericStage(
            humanBeef ? new HumanBeef()
                : StageDescription.getFighter(fighterNum),
            (stageNum < 3) ? stageNum : stageNum - 1));
  }

  public void humanOpponentWonStage() {
    stageNum++;
    startVS();
  }

  public void startVS() {
    if (stageNum == 3) {
      GraphicsSource.setRenderListener(
          new BonusStage(
              humanBeef ? new HumanBeef()
                        : StageDescription.getFighter(fighterNum)));
    } else if (stageNum < 3) {
      GraphicsSource.setRenderListener(
          new VS(humanBeef ? 6 : fighterNum-1, stageNum));
    } else if (stageNum <= 6) {
      GraphicsSource.setRenderListener(
          new VS(humanBeef ? 6 : fighterNum-1, stageNum - 1));
    } else {
      GraphicsSource.setRenderListener(
          new WinningScene(humanBeef ? 7 : fighterNum));
    }
  }

  public void humanOpponentLostStage() {
    InputFactory.getInputSource().setInputListener(this);
    GraphicsSource.setRenderListener(new Continue());
  }

  public void resetTheGame() {
    humanBeef = pressedStart = false;
    startStage = stageNum = 0;
    InputFactory.getInputSource().setInputListener(this);
    GraphicsSource.setRenderListener(
        Introduction.getInstance(Introduction.STATE_NAMEUP));
  }

  private void exitOnVersion() {
    System.out.println("Meat Fighter\n"
        + "Version " + MEAT_FIGHTER_VERSION + "\n"
        + "Copyright (C) 2003  Michael Birken\n"
        + "\n"
        + "This program is free software; you can redistribute it and/or modify\n"
        + "it under the terms of the GNU General Public License as published by\n"
        + "the Free Software Foundation; either version 2 of the License, or\n"
        + "(at your option) any later version.\n"
        + "\n"
        + "This program is distributed in the hope that it will be useful,\n"
        + "but WITHOUT ANY WARRANTY; without even the implied warranty of\n"
        + "MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the\n"
        + "GNU General Public License for more details.\n"
        + "\n"
        + "You should have received a copy of the GNU General Public License\n"
        + "along with this program; if not, write to the Free Software\n"
        + "Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA\n"
        + "\n"
        + "Check out http://www.meatfighter.com for Meat Fighter news and updates.\n"
        + "Meat Fighter and JaminWare are trademarks of Michael Birken.\n"
        + "All Rights Reserved.\n");
    System.exit(EXIT_VERSION);
  }

  private void exitOnFatal(Throwable t) {
    System.out.println("Fatal error: " + t.getMessage());
    System.out.println("Meat Fighter version: " + MEAT_FIGHTER_VERSION);
    System.out.println("Java version: " + System.getProperty("java.version"));
    System.out.println("OS: " + System.getProperty("os.name") + " "
        + System.getProperty("os.version"));
    System.out.println("Details:");
    t.printStackTrace(System.out);
    System.exit(EXIT_FATAL);
  }

  final static StageDescription[] STAGEDESCRIPTION = {
      new StageDescription(662,138,30),
      new StageDescription(110,274,15),
      new StageDescription(50,189,45),
      new StageDescription(243,275,10),
      new StageDescription(240,338,30),
      new StageDescription(247,356,30) };

  Image img;
  int stageNum, fighterNum, secret;

  public void endGame() {
    GraphicsSource.stopAnimation();
    GraphicsSource.exitDisplayMode();
    Jukebox.disposeAll();
    System.exit(0);
  }

  // L R U D B K B K B  1
  // L R U D B K B K D  2
  // L R U D B K B K K  3
  // L R U D B K B K L  4
  // L R U D B K B K R  5
  // L R U D B K B K U  6
  // L R U D B K B K P  7
  // L R U D P          beef

  public void inputLeft() {
    switch(secret) {
      case 0:
        secret = 1;
        break;
      case 8:
        secret = 0;
        startStage = 4;
        Jukebox.SPLAT.play();
        break;
      default:
        secret = 0;
    }
  }

  public void inputRight() {
    switch(secret) {
      case 1:
        secret = 2;
        break;
      case 8:
        secret = 0;
        startStage = 5;
        Jukebox.SPLAT.play();
        break;
      default:
        secret = 0;
    }
  }

  public void inputUp() {
    switch(secret) {
      case 2:
        secret = 3;
        break;
      case 8:
        secret = 0;
        startStage = 6;
        Jukebox.SPLAT.play();
        break;
      default:
        secret = 0;
    }
  }

  public void inputDown() {
    switch(secret) {
      case 3:
        secret = 4;
        break;
      case 8:
        secret = 0;
        startStage = 2;
        Jukebox.SPLAT.play();
        break;
      default:
        secret = 0;
    }
  }

  public void inputBlock() {
    switch(secret) {
      case 4:
        secret = 5;
        break;
      case 6:
        secret = 7;
        break;
      case 8:
        secret = 0;
        startStage = 1;
        Jukebox.SPLAT.play();
        break;
      default:
        secret = 0;
    }
  }

  public void inputKick() {
    switch(secret) {
      case 5:
        secret = 6;
        break;
      case 7:
        secret = 8;
        break;
      case 8:
        secret = 0;
        startStage = 3;
        Jukebox.SPLAT.play();
        break;
      default:
        secret = 0;
    }
  }

  public void inputPunch() {
    switch(secret) {
      case 4:
        secret = 0;
        humanBeef = true;
        Jukebox.SPLAT.play();
        break;
      case 8:
        secret = 0;
        startStage = 7;
        Jukebox.SPLAT.play();
        break;
      default:
        secret = 0;
    }
  }
}